@@ -1,14 +1,39 @@
 package HPUX::FS;
 
-require Exporter;
-@ISA = qw(Exporter);
-
-@EXPORT = qw();            # symbols to export by default
-
-$VERSION = sprintf "%d.%03d", q$Revision: 0.01 $ =~ /(\d+)\.(\d+)/;
-
+use 5.006;
 use strict;
-use Carp ;
+#use warnings;
+
+require Exporter;
+use AutoLoader qw(AUTOLOAD);
+
+our @ISA = qw(Exporter);
+
+# Items to export into callers namespace by default. Note: do not export
+# names by default without a very good reason. Use EXPORT_OK instead.
+# Do not simply export all your public functions/methods/constants.
+
+# This allows declaration	use HPUX::FS ':all';
+# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
+# will save memory.
+our %EXPORT_TAGS = ( 'all' => [ qw(
+	
+) ] );
+
+our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+
+our @EXPORT = qw(
+	
+);
+our $VERSION = '1.03';
+
+# Preloaded methods go here.
+
+# Autoload methods go after =cut, and are processed by the autosplit program.
+
+### start
+
+use Carp;
 use Storable;
 
 sub new
@@ -59,9 +84,9 @@ sub new
     my @first_command;
     my @second_command;
     my @third_command;
-    my $first_command;
-    my $second_command;
-    my $third_command;
+    my $first_command="";
+    my $second_command="";
+    my $third_command="";
     my %filesys_hash;
     my $filesys_hash = \%filesys_hash;
     my $fstab_line;
@@ -132,7 +157,7 @@ sub new
 					directory	=> $split_fstab_line[1],
 					type		=> $split_fstab_line[2],
 					options		=> $split_fstab_line[3],
-					backup_freq	=> $split_fstab_line[4..5],
+					backup_freq	=> $split_fstab_line[4-5],
 					kbytes		=> "NA",
 					kbytes_used	=> "NA",
 					kbytes_avail	=> "NA",
@@ -267,12 +292,15 @@ sub get_filesystem_attr {
 	$attribute = $self->{$item}->{$attr};	
 	return $attribute;
 			}
+### end
+
 1;
-
 __END__
+# Below is stub documentation for your module. You better edit it!
 
+=head1 NAME
 
-HPUX::FS - Perl module to handle HPUX ioscan command
+HPUX::FS - Perl function to handle HPUX filesystem stats
 
 =head1 SYNOPSIS
 
@@ -373,3 +401,41 @@ Christopher White <chrwhite@seanet.com>
 Copyright (C) 2001 Christopher White.  All rights reserved.  this program is fre
 e software;  you can redistribute it and/or modify it under the same terms as pe
 rl itself.
+
+### end
+
+1;
+__END__
+# Below is stub documentation for your module. You better edit it!
+
+=head1 NAME
+
+HPUX::FS - Perl extension for blah blah blah
+
+=head1 SYNOPSIS
+
+  use HPUX::FS;
+  blah blah blah
+
+=head1 DESCRIPTION
+
+Stub documentation for HPUX::FS, created by h2xs. It looks like the
+author of the extension was negligent enough to leave the stub
+unedited.
+
+Blah blah blah.
+
+=head2 EXPORT
+
+None by default.
+
+
+=head1 AUTHOR
+
+A. U. Thor, E<lt>a.u.thor@a.galaxy.far.far.awayE<gt>
+
+=head1 SEE ALSO
+
+L<perl>.
+
+=cut
